%Simplex Program for computing 7 elements of the Light-Time Effect of the system !!!
clear;    %clear all variables in memory

%----------------INPUT PARAMETERS: ----------------------
fid = fopen('Parameters.txt','r');  %input file  *.in  with the initial LITE parameters, only for reading
row=0;
i=0;
while row ~= -1
    i=i+1;
    row=fgets(fid);
    if i == 1
        BBB = strread(row, '%s', 'delimiter', ' ');
        Star = cellstr([BBB(1)]);
%         Star = cellstr([BBB(1) BBB(2) BBB(3) BBB(4) BBB(5) BBB(6) BBB(7) BBB(8) BBB(9) BBB(10)]); 
%         Star = cellstr(BBB);
        Star = Star';
    else
       if row ~= -1
         A=sscanf(row,'%f');
         Y(i-1)=A(1);
         F(i-1)=A(2);
       end
    end
end
status = fclose('all');      %close the file
clear A row i fid status BBB;    %it is better to clear all unnecessary variables from the memory
Y=Y';
%------------------------------------------------------------

%---------------INPUT DATA POINTS (=minima times): ---------------------
fid2 = fopen('Minima.txt','r');  %input file  *.min  with the data (times of minima - JDi), open only for reading
row=0;
i=0;
while row ~= -1
    i=i+1;
    row=fgets(fid2);
    if i ~= 1
       if row ~= -1
         A=sscanf(row,'%f');
         Minima(i-1)=A(1);
         Weight(i-1)=A(2);
     end
    end
end
status = fclose('all');
clear A row fid2 status;
%----------------------------------------------------------------

N=i-2;      %number of data points (minima times)
param=8;     %number of parameters to fit (only 8 parameters of the LITE and from quadratic term)
alfa=1.0;     %parameters of the simplex itself:
beta=0.35;
gama=2.0;
delta=0.5;

Minima=Minima';     %minima times
Weight=Weight';      %weights of individual minima times
JDi=Minima+2400000;   %Juliane date of individual minima times

clear Minima;

JD00=Y(1);    %here are the 8 parameters of the LITE from the Y matrix
JD0F=F(1);
P=Y(2);
PF=F(2);
p3=Y(3);
p3F=F(3);
T0=Y(4);
T0F=F(4);
A=Y(5);
AF=F(5);
omega=Y(6);
omegaF=F(6);
excen=Y(7);
excenF=F(7);
qmt=Y(8);
qmtF=F(8);
M1=Y(9);  %mass of the primary star
M2=Y(10);  %mass of the secondary star
paralax=Y(11);
Fonts=Y(12);
Lines=Y(13);
ColFigs=Y(14);
clear Y;

M12=M1+M2;
MaxExc=0.83;  %limit for eccentricity to be reached

EpoLin=Epoch(JDi,JD00,P);    %Epoch of individual minima times

% for i=1:length(Epo)
%     if Epo(i) > 40000
%         Epo(i)=Epo(i)+0.5;
%     elseif Epo(i)>56000
%         Epo(i)=Epo(i)+1;
%     end
% end

for i=1:length(JDi)
    clear C;
    C(1)=-1*(qmt+0.00000001)*10^(-10);
    C(2)=(-1)*P;
    C(3)=JDi(i)-JD00;
    EpKoren=roots(C);
    Rozdil1 = abs(EpoLin(i)-EpKoren(1));
    Rozdil2 = abs(EpoLin(i)-EpKoren(2));
    if min(Rozdil1,Rozdil2) == Rozdil1 
        Epo0(i) = EpKoren(1);
    else
        Epo0(i) = EpKoren(2);
    end
    clear Rozdil1 Rozdil2;
end

Epo0=Epo0';
clear EpoLin;
O=JDi-JD00-P*Epo0;        %O-C difference

for i = 1:N
   if ((Epo0(i)-round(Epo0(i))) >= -0.25) & ((Epo0(i)-round(Epo0(i))) <= 0.25)
      vysledek(i)=round(Epo0(i));             %primary minima times
  else
      if ((Epo0(i)-round(Epo0(i))) > 0.25) & ((Epo0(i)-round(Epo0(i))) < 0.75)
         vysledek(i)=round(Epo0(i))+0.5;   %secondary minima times
     else
         if ((Epo0(i)-round(Epo0(i))) > -0.75) & ((Epo0(i)-round(Epo0(i))) < -0.25)
            vysledek(i)=round(Epo0(i))-0.5;       %secondary minima times
        else
            disp('Something is wrong!')
         end
      end
   end
end
%vysledek=sort(vysledek);

clear O E11 E21 Epo0;
Epo0=vysledek';
O=JDi-JD00-P*Epo0;        %O-C difference

%===========Calculation of the uncertainity of the ephemeris!!!===================
M=2;   %number of parameters to fit (only 2 parameters)
%--------------------------------------------------
yiminusyxi= JDi - (JD00+P*Epo0);   %y_i - y(x_i,JD0,P)
sigmaKvadr=(sum(yiminusyxi.*yiminusyxi))/(N-M);

dydJD0  =  ((JD00+0.0001+P*Epo0) - (JD00+P*Epo0))/0.0001;    %d(OminusC)/dJD0
dydP  =  ((JD00+(P+0.0000001)*Epo0) - (JD00+P*Epo0))/0.0000001;       %d(OminusC)/dP

for k = 1:M
    for l = 1:M
        switch k
            case 1
                first = dydJD0;
            case 2 
                first = dydP;
        end
        switch l
            case 1
                second = dydJD0;
            case 2 
                second = dydP;
        end
        alpha(k,l) = (1/sigmaKvadr)*(sum((first).*(second)));
    end
end

C=inv(alpha);
sigma=sqrt(C);
% disp('Absolute errors:');
sigmaJD0a=sigma(1,1);
sigmaPa=sigma(2,2);

% disp(['Relative errors: JD0 => ',num2str(100*sigmaJD0/JD00,'%4.4f'),' %']);
% disp(['Relative errors: P => ',num2str(100*sigmaP/P,'%4.4f'),' %']);
clear alpha C sigma M yiminusyxi sigmaKvadr dydJD0 dydP k l first second;
%=========================================================================

j=1;
k=1;
for i = 1:N
   switch round(10*abs(Epo0(i)-round(Epo0(i))))
   case 0
      E11(j)=Epo0(i);    %primary minima times
      Occ1(j)=O(i);
      B1(j)=Weight(i);
      j=j+1;
   case 5            %secondary minima times
      E21(k)=Epo0(i);
      Occ2(k)=O(i);   
      B2(k)=Weight(i);
      k=k+1;
   end
end

m=1;
n=1;
o=1;
o1=1;
remove=0;       %some minima times were eliminated
for i = 1:j-1     %primary minima times
   switch B1(i)
   case 0          %weight = 0  =>  ignore this minimum!
      remove=remove+1;     %removed minima times (=weight 0)
   case 1        %visual primary minima times
      E1v(n)=E11(i);
      O1v(n)=Occ1(i);
      n=n+1;
   case 3       %photographic primary minima times, worse quality
      E1pp(o1)=E11(i);
      O1pp(o1)=Occ1(i);
      o1=o1+1;
   case 5        %photographic primary minima times
      E1p(o)=E11(i);
      O1p(o)=Occ1(i);
      o=o+1;
   case 10       %ccd primary minima times
      E1c(m)=E11(i);
      O1c(m)=Occ1(i);
      m=m+1;
   case 30       %ccd primary minima times
      E1c(m)=E11(i);
      O1c(m)=Occ1(i);
      m=m+1;
   end
end

p=1;
q=1;
r=1;
o2=1;
for i = 1:k-1     %secondary minima times
   switch B2(i)
   case 0
      remove=remove+1;   %removed secondary minima times
   case 1         %visual secondary minima times
      E2v(p)=E21(i);
      O2v(p)=Occ2(i);
      p=p+1;
   case 3       %photographic secondary minima times, worse quality
      E2pp(o2)=E21(i);
      O2pp(o2)=Occ2(i);
      o2=o2+1;
   case 5         %photographic secondary minima times
      E2p(q)=E21(i);
      O2p(q)=Occ2(i);
      q=q+1;
   case 10        %ccd secondary minima times
      E2c(r)=E21(i);
      O2c(r)=Occ2(i);
      r=r+1;
   case 10        %ccd secondary minima times
      E2c(r)=E21(i);
      O2c(r)=Occ2(i);
      r=r+1;
    end
end

minimumE=1000*floor(min(Epo0)/1000);
maximumE=1000*ceil(max(Epo0)/1000)+1000;
minimumO=Minimum(O,Weight,N)-0.02;
maximumO=Maximum(O,Weight,N)+0.02;

Ep=minimumE:10:maximumE;        %plot a curve
JDi0=Ep*P+JD00;
Oc=OminusC(JDi0,T0,A,p3,omega,excen)+10^(-10)*qmt*Ep.*Ep;

%--------------- HERE PLOT THE FIGURE: --------------------
figure(1);
set(gca,'box','on');
hold on
if n > 1 plot(E1v,O1v,'k.','MarkerSize',6); end    %plot primary visual minima times
if o1 > 1 plot(E1pp,O1pp,'k.','MarkerSize',8); end  %primary photographic minima times, worse quality
if o > 1 plot(E1p,O1p,'k.','MarkerSize',12); end   %primary photographic minima times
if m > 1 plot(E1c,O1c,'k.','MarkerSize',17); end   %primary ccd minima times
if p > 1 plot(E2v,O2v,'ko','MarkerSize',2); end    %secondary visual minima times
if o2 > 1 plot(E2pp,O2pp,'ko','MarkerSize',2); end  %secondary photographic minima times, worse quality
if q > 1 plot(E2p,O2p,'ko','MarkerSize',3); end    %secondary photographic minima times
if r > 1 plot(E2c,O2c,'ko','MarkerSize',4); end    %secondary ccd minima times
plot(Ep,Oc,'r-','LineWidth',Lines);
plot(Ep,+10^(-10)*qmt*Ep.*Ep,'b-.');
axis([minimumE maximumE minimumO maximumO]);
set(gca,'PlotBoxAspectRatio',[2.4 1 1]);
xlabel('Epoch');   %labeling the axis
ylabel('O-C (Days)');
title('O-C diagram');   %labeling the figure
hold off
%--------------------------------------------------------------------------
%clear E1c E1v E1p E2c E2v E2p E1pp E2pp O1pp O2pp O1v O1c O1p O2v O2c O2p j k m n o o1 p q r o2 B1 B2 Occ1 Occ2 E11 E21 Epo0 O;   %clear all unnecessary variables
%---------------------------------------------------------------------------------------------------------
PocitadloVnejsi=0;
quadr=input('Do you also want to use the quadratic term (mass transfer) \n besides the LITE (1) or only LITE (0), or only quadratic term (2) ?');

if quadr ~= 1
    if quadr ~= 0
        if quadr ~= 2
            disp(['']);
            disp('Somethig is wrong, continue with no quadratic term.');
            quadr=0;
            disp(['']);
        end
    end
end

count = input('How many "steps" in one calculation of the simplex algorithm? \n (a few, depends on the speed of the computer): ');

disp([' ']);
input('Now the numbers on the screen represent (decreasing) sum \nof the square residuals from all minima times \nin the best vertex of the actual simplex.');

contin = 1;
while contin == 1
        PocitadloVnejsi=PocitadloVnejsi+1;

    %---------------- HERE THE SIMPLEX ALGORITHM!!! ----------------->
    if JD0F == 1
        JD0=JD00+random('Normal',0,0.011,1,param+1);   %define the vertexes of the initial simplex (x,y,...)=(JD0i,P0i,...):
        JD0(1)=JD00;
    else
        JD0=JD00+random('Normal',0,0.0,1,param+1);   %define the vertexes of the initial simplex (x,y,...)=(JD0i,P0i,...):
        JD0(1)=JD00;
    end
    
    if PF == 1
        P0=P+random('Normal',0,0.000115,1,param+1);
        P0(1)=P;
    else
        P0=P+random('Normal',0,0.0,1,param+1);
        P0(1)=P;
    end
    
    if p3F == 1
        p30=p3+random('Normal',0,5500,1,param+1);
        p30(1)=p3;
    else
        p30=p3+random('Normal',0,0,1,param+1);
        p30(1)=p3;
    end
    
    if T0F == 1
        T00=T0+random('Normal',0,3000,1,param+1);
        T00(1)=T0;
    else
        T00=T0+random('Normal',0,0,1,param+1);
        T00(1)=T0;
    end
    
    if omegaF == 1
        omeg0=omega+random('Normal',0,140.0,1,param+1);
        omeg0(1)=omega;
    else
        omeg0=omega+random('Normal',0,0.0,1,param+1);
        omeg0(1)=omega;
    end

    if excenF == 1
        exc0=excen+random('Normal',0,0.05,1,param+1);
        exc0(1)=excen;
        for i = 1:param+1
            if exc0(i) >= MaxExc
                exc0(i)=MaxExc;
            end
        end
    else
        exc0=excen+random('Normal',0,0.0,1,param+1);
        exc0(1)=excen;
    end

    if quadr == 2        %the case when we want to use only the quadratic term
        A0=random('Normal',0,0.0,1,param+1);
        if qmtF == 1
            q0=qmt+random('Normal',0,0.075,1,param+1);
            q0(1)=qmt;
        else
            q0=qmt+random('Normal',0,0.0,1,param+1);
            q0(1)=qmt;
        end
    elseif quadr == 1    %the case when we want to use the quadratic term with the LITE together
        if AF == 1
            A0=A+random('Normal',0,0.085,1,param+1);
            A0(1)=A;
        else
            A0=A+random('Normal',0,0.0,1,param+1);
            A0(1)=A;
        end
        if qmtF == 1
            q0=qmt+random('Normal',0,0.27,1,param+1);
            q0(1)=qmt;
        else
            q0=qmt+random('Normal',0,0.0,1,param+1);
            q0(1)=qmt;
        end
    else                %the case when we want to compute only LITE
        q0=random('Normal',0,0.0,1,param+1);
        if AF == 1
            A0=A+random('Normal',0,0.07,1,param+1);
            A0(1)=A;
        else
            A0=A+random('Normal',0,0.0,1,param+1);
            A0(1)=A;
        end
    end

    konst=450;
    abacus=konst+1;
    fl=0.001;
    fl0=0;

    for i = 1:konst+1
        sumactvercu(i)=0;
    end
    sumactvercu(abacus)=1;
  while sumactvercu(abacus) ~= sumactvercu(abacus-konst)   %podminka zastaveni, kdyz se jiz suma ctvercu nemeni!
    fl0=fl;
    abacus=abacus+1;
    
    %---------zde vypocet sumy ctvercu odchylek od vsech mereni pri zapocteni LITE hypotezy---------
    for i=1:param+1
        f0(i) = SumOfSquaresLITE(JDi,Weight,Epo0,JD0(i),P0(i),T00(i),A0(i),p30(i),omeg0(i),exc0(i),q0(i));
    end
    %-----------------------------------------------------------------------------------------------
    
    Sort0=sort(f0);     %sort the vector from the smallest element -> fh is the highest, fl the smallest
    fh=Sort0(param+1);
    fs=Sort0(param);
    fl=Sort0(1);
    sumactvercu(abacus)=fl;   %nejlepsi, nejmensi suma ctvercu odchylek
    
    if mod(abacus,50)==0
        disp(['Sum of square residuals: ', num2str(fl,25), '  Number of iterations: ', int2str(abacus-konst), '/', int2str(PocitadloVnejsi), '/',int2str(count),]);
    end
  
    for i=1:param+1
        if f0(i)==Sort0(param+1)     %gives the number of the worst vertex
            h=i;
        elseif f0(i)==Sort0(param)    %gives the number of the second worst vertex
            s=i;
        else
            if f0(i)==Sort0(1)    %gives the number of the best vertex
                l=i;
            end
        end
    end
    clear f0 Sort0;
    
    for i=1:param
        xc(i)=0;
    end

    for i=1:param+1                      %calculate the center of the simplexu without the worst vertex i<>h
        if i~=h
            xc(1)=xc(1)+1/param*(JD0(i));    %coordinate of the centre in the JD0i
            xc(2)=xc(2)+1/param*(P0(i));     %coordinate of the center in the P0i, etc...
            xc(3)=xc(3)+1/param*(p30(i));
            xc(4)=xc(4)+1/param*(T00(i));
            xc(5)=xc(5)+1/param*(A0(i));
            xc(6)=xc(6)+1/param*(omeg0(i));
            xc(7)=xc(7)+1/param*(exc0(i));
            xc(8)=xc(8)+1/param*(q0(i));
        end
    end
    %     1      2      3     4     5      6        7       8
    xh=[JD0(h),P0(h),p30(h),T00(h),A0(h),omeg0(h),exc0(h),q0(h)];      %coordinates of the worst vertex
    xl=[JD0(l),P0(l),p30(l),T00(l),A0(l),omeg0(l),exc0(l),q0(l)];      %coordinates of the best vertex
    xs=[JD0(s),P0(s),p30(s),T00(s),A0(s),omeg0(s),exc0(s),q0(s)];      %coordinates of the second worst vertex
    
    x=[JD0',P0',p30',T00',A0',omeg0',exc0',q0'];  %coordinates of all the 8 vertexes of simplex - in all 7 parametrs
    
    xalfa=(1+alfa)*xc-alfa*xh;    %reflection             !|
%   xbeta=(1-beta)*xc+beta*xh;    %contraction            !|
%   xgama=(1-gama)*xc+gama*xh;    %expansion              !|
    xdelta=xl+delta*(xh-xl);      %shrinkage              !|
%   for beta and gama see lower !

    %---------zde vypocet sumy ctvercu odchylek od vsech mereni pri zapocteni LITE hypotezy pro bod xalfa---------
    f0a = SumOfSquaresLITE(JDi,Weight,Epo0,xalfa(1),xalfa(2),xalfa(4),xalfa(5),xalfa(3),xalfa(6),xalfa(7),xalfa(8));
    %-------------------------------------------------------------------------------------------------------------
    %---------zde vypocet sumy ctvercu odchylek od vsech mereni pri zapocteni LITE hypotezy pro bod xdelta--------
    f0d = SumOfSquaresLITE(JDi,Weight,Epo0,xdelta(1),xdelta(2),xdelta(4),xdelta(5),xdelta(3),xdelta(6),xdelta(7),xdelta(8));
    %-------------------------------------------------------------------------------------------------------------
    
    if f0a < fl
        xgama=(1-gama)*xc+gama*((1+alfa)*xc-alfa*xh);     %xbeta(xalfa(xh)) !
        %---------zde vypocet sumy ctvercu odchylek od vsech mereni pri zapocteni LITE hypotezy pro bod xgama--------
        f0g = SumOfSquaresLITE(JDi,Weight,Epo0,xgama(1),xgama(2),xgama(4),xgama(5),xgama(3),xgama(6),xgama(7),xgama(8));
        %-------------------------------------------------------------------------------------------------------------
        if f0g < f0a
            for i=1:param
                x(h,i)=xgama(i);
            end
            Inp(abacus-konst)=char('g');
        else
            for i=1:param
                x(h,i)=xalfa(i);
            end
            Inp(abacus-konst)=char('a');
        end
    else
        if f0a <= fs
            for i=1:param
                x(h,i)=xalfa(i);
            end
             Inp(abacus-konst)=char('a');
         else
            if f0a > fh
                xbeta=(1-beta)*xc+beta*xh;
                %---------zde vypocet sumy ctvercu odchylek od vsech mereni pri zapocteni LITE hypotezy pro bod xbeta--------
                f0b = SumOfSquaresLITE(JDi,Weight,Epo0,xbeta(1),xbeta(2),xbeta(4),xbeta(5),xbeta(3),xbeta(6),xbeta(7),xbeta(8));
                %-------------------------------------------------------------------------------------------------------------
            else
                xbeta=(1-beta)*xc+beta*((1+alfa)*xc-alfa*xh);     %xbeta(xalfa(xh)) !
                %---------zde vypocet sumy ctvercu odchylek od vsech mereni pri zapocteni LITE hypotezy pro bod xbeta--------
                f0b = SumOfSquaresLITE(JDi,Weight,Epo0,xbeta(1),xbeta(2),xbeta(4),xbeta(5),xbeta(3),xbeta(6),xbeta(7),xbeta(8));
                %-------------------------------------------------------------------------------------------------------------
            end
            if f0b > fh
                for j=1:param+1
                   for i=1:param
                       x(j,i)=xl(i)+delta*(x(j,i)-xl(i));
                   end
                end
                Inp(abacus-konst)=char('d');
            else
                for i=1:param
                    x(h,i)=xbeta(i);
                end
                Inp(abacus-konst)=char('b');
            end
        end
    end
    clear JD0 P0 p30 aD T00 A0 omeg0 exc0 q0;
    
    for i=1:param+1
       JD0(i)=x(i,1);  %arbitrariness to which vertexes assign which values, in fact we don't know which is now the best and the worst
       P0(i)=x(i,2);
       p30(i)=x(i,3);
       T00(i)=x(i,4);
       if x(i,5) < 0
           A0(i)=-(x(i,5));     %negative amplitudes ignore
       else
           A0(i)=x(i,5);
       end
       omeg0(i)=1/1000000*mod(round(abs(1000000*x(i,6))),360000000);   %convert Rad->Deg and also to 4 decimals precision and in the range (0,360) deg!
       if x(i,7) <= 0           %negative eccentricities ignore 
           exc0(i)=0;
       else
           exc0(i)=x(i,7);
       end
       if exc0(i) >= MaxExc
           exc0(i)=MaxExc;
       end
       q0(i)=x(i,8);
    end
end
disp([' ']);
disp('Here are shown the individual simplex steps. a-reflection, b-contraction, d-shrinkage, g-expansion');
disp(Inp);

JD00=JD0(l);
P=P0(l);
p3=p30(l);
T0=T00(l);
A=A0(l);
omega=omeg0(l);
excen=exc0(l);
qmt=q0(l);

minimumE=1000*floor(min(Epo0)/1000);
maximumE=1000*ceil(max(Epo0)/1000)+1000;

fm3=1/(p3/365.24)^2*((173.14*A/sqrt(1-(excen*cos(omega*pi/180))^2 ))^3);   %mass function

disp([' ']);
disp(['Initial minimum:  ',num2str(JD00),' HJD']);
disp(['Period of the eclipsing pair: ',num2str(P,'%2.9f'),' days']);
disp(['Period of the 3. body: ',num2str(p3,'%6.2f'),' days']);
disp(['Period of the 3. body: ',num2str(p3/365.24,'%3.3f'),' years']);
disp(['Periastron passage: ',num2str(T0,'%8.2f'),' HJD']);
disp(['Semiamplitude of the LITE: ',num2str(A,'%1.6f'),' days']);
disp(['Argument of periastron: ',num2str(omega,'%3.2f'),' degree']);
disp(['Eccentricity of the 3.body orbit: ',num2str(excen)]);
disp(['Mass transfer rate: ',num2str(qmt)]);
disp(['Mass function of the 3. body: ',num2str(fm3),' M_Sun']);
disp(['Altogether: ',int2str(N),' measurements']);
disp(['And from those ',int2str(remove),' neglected']);
disp(['The computation ran ', int2str(PocitadloVnejsi), ' times.']);
    
if PocitadloVnejsi < count    %podminka ukonceni celeho cyklu!!!
    contin = 1;
else
    contin = 0;
end

end   %end of the whole cycle !!

O=JDi-JD00-P*Epo0;       %difference O-C

j=0;
for i = 1:N
   if Weight(i)>0
       j=j+1;
       V(j)=O(i);
   end
end

minimumO3=min(V)-0.03;    %result
maximumO3=max(V)+0.03;   %result 

j=1;
k=1;
for i = 1:N
   switch round(10*abs(Epo0(i)-round(Epo0(i))))
   case 0
      E11(j)=Epo0(i);    %primar minimum
      Occ1(j)=O(i);
      B1(j)=Weight(i);
      JD01(j)=JDi(i);
      j=j+1;
   case 5            %secondar minimum
      E21(k)=Epo0(i);
      Occ2(k)=O(i);
      B2(k)=Weight(i);
      JD02(k)=JDi(i);
      k=k+1;
   end
end

m=1;
n=1;
o=1;
o1=1;
for i = 1:j-1     %primar minimum
   switch B1(i)
   case 1        %visual primar minimum
      E1v(n)=E11(i);
      O1v(n)=Occ1(i);
      n=n+1;
   case 3       %photographic prim.min worse quality
      E1pp(o1)=E11(i);
      O1pp(o1)=Occ1(i);
      o1=o1+1;
   case 5        %photographic primar minimum
      E1p(o)=E11(i);
      O1p(o)=Occ1(i);
      o=o+1;
   case 10       %ccd primar minimum
      E1c(m)=E11(i);
      O1c(m)=Occ1(i);
      m=m+1;
   case 30       %ccd primar minimum
      E1c(m)=E11(i);
      O1c(m)=Occ1(i);
      m=m+1;
   end
end

p=1;
q=1;
r=1;
o2=1;
for i = 1:k-1     %secondar minimum
   switch B2(i)
   case 1         %visual secondar minimum
      E2v(p)=E21(i);
      O2v(p)=Occ2(i);
      p=p+1;
   case 3       %photographic sec.min worse quality
      E2pp(o2)=E21(i);
      O2pp(o2)=Occ2(i);
      o2=o2+1;
   case 5         %photographic secondar minimum
      E2p(q)=E21(i);
      O2p(q)=Occ2(i);
      q=q+1;
   case 10        %ccd secondar minimum
      E2c(r)=E21(i);
      O2c(r)=Occ2(i);
      r=r+1;
   case 30        %ccd secondar minimum
      E2c(r)=E21(i);
      O2c(r)=Occ2(i);
      r=r+1;
   end
end

Ep3=minimumE:10:maximumE;        %plot a curve
JDi0=Ep*P+JD00;
Oc3=OminusC(JDi0,T0,A,p3,omega,excen)+10^(-10)*qmt*Ep3.*Ep3;
OnlyMT=+10^(-10)*qmt*Ep3.*Ep3;

%-------------- 
clear CC;
CC=['3.txt'];
BB=char(Star);
QQ=sprintf([BB CC]);

OutputData=[JDi0; Ep3; Oc3; OnlyMT];

BB=char(Star);
%-------------- O U T P U T   DATA FILE --------------->>>
fid = fopen(QQ,'w');
fprintf(fid,'%s',BB,': JDi -- Epoch -- Total -- OnlyParab');
fprintf(fid,'%s\n','');
fprintf(fid,'%12.6f   %6.5f   %2.6f   %2.6f\n',OutputData);
status=fclose('all');
%-------------- 
clear OutputData QQ BB CC fid;

minJD=minimumE*P+JD00-2400000;
maxJD=maximumE*P+JD00-2400000;
minDate=JulToDate(minJD+2400000);
maxDate=JulToDate(maxJD+2400000);
minPer3=minimumO3/P;
maxPer3=maximumO3/P;

CC=['O-C diagram '];
BB=char(Star);
QQ=sprintf([CC BB]);

figure(5);
clf;
if m > 1 plot(E1c,O1c,'k.','MarkerSize',17); O31c=O1c; end   %prim ccd min
hold on
if n > 1 plot(E1v,O1v,'k.','MarkerSize',6); O31v=O1v; end    %prim vis min
if o > 1 plot(E1p,O1p,'k.','MarkerSize',12); O31p=O1p; end   %prim phot min
if p > 1 plot(E2v,O2v,'ko','MarkerSize',2); O32v=O2v; end    %sec vis min
if q > 1 plot(E2p,O2p,'ko','MarkerSize',3); O32p=O2p; end    %sec phot min
if r > 1 plot(E2c,O2c,'ko','MarkerSize',4); O32c=O2c; end    %sec ccd min
if o1 > 1 plot(E1pp,O1pp,'k.','MarkerSize',8); O31pp=O1pp; end   %prim phot min worse quality
if o2 > 1 plot(E2pp,O2pp,'ko','MarkerSize',2); O32pp=O2pp; end   %prim phot min worse quality
plot(Ep3,Oc3,'r-','LineWidth',Lines);
plot(Ep3,+10^(-10)*qmt*Ep3.*Ep3,'b-.','LineWidth',Lines);
set(gca,'FontSize',Fonts);
axis([minimumE maximumE minimumO3 maximumO3]);
set(gca,'XAxisLocation','bottom', 'FontSize', Fonts);
set(gca,'box','off');
set(gca,'YAxisLocation','left', 'FontSize', Fonts); 
%set(gca,'PlotBoxAspectRatio',[1.8 1 1]);
set(gca,'PlotBoxAspectRatio',[2.4 1 1]);
xlabel('Epoch', 'FontSize', Fonts);
set(gca,'FontSize',Fonts);
ylabel('O-C (days)', 'FontSize', Fonts);

%RECT=[0.13 0.80503 0.775 0.0001];
RECT=[0.13 0.733603 0.775 0.0001];
axes('position', RECT);
set(gca,'FontSize',Fonts);
axis([minDate maxDate -0.01 0.01]);
%set(gca,'XTickLabel','-15000|-10000|-5000|0|5000|10000|15000');
set(gca,'TickDir','out', 'FontSize', Fonts);
set(gca,'XAxisLocation','top');
set(gca,'XAxisLocation','bottom');

RECT=[0.13 0.733603 0.775 0.0001];
axes('position', RECT);
set(gca,'FontSize',Fonts);
axis([minJD+2400000 maxJD+2400000 -0.0001 0.0001]);
set(gca,'XLimMode','manual');
if (maxJD-minJD) < 7000 %cca 19 let
    set(gca,'XTick',[ 2417000.0 2418000.0 2419000.0 2420000.0 2421000.0 2422000.0 2423000.0 2424000.0 2425000.0  2426000.0 2427000.0 2428000.0 2429000.0 2430000.0 2431000.0 2432000.0 2433000.0 2434000.0 2435000.0 2436000.0 2437000.0 2438000.0 2439000.0 2440000.0 2441000.0 2442000.0 2443000.0 2444000.0 2445000.0 2446000.0 2447000.0 2448000.0 2449000.0 2450000.0 2451000.0 2452000.0 2453000.0 2454000.0 2455000.0 2456000.0 2457000.0 2458000.0 2459000.0 2460000.0 ]);
    set(gca,'XTickLabel','2417000|2418000|2419000|2420000|2421000|2422000|2423000|2424000|2425000| 2426000|2427000|2428000|2429000|2430000|2431000|2432000|2433000|2434000|2435000|2436000|2437000|2438000|2439000|2440000|2441000|2442000|2443000|2444000|2445000|2446000|2447000|2448000|2449000|2450000|2451000|2452000|2453000|2454000|2455000|2456000|2457000|2458000|2459000|2460000');    
elseif ((maxJD-minJD) >= 7000) & ((maxJD-minJD) < 15000)  %od cca 19 let do 27 let
    set(gca,'XTick',[ 2418000.0 2420000.0 2422000.0 2424000.0 2426000.0 2428000.0 2430000.0 2432000.0 2434000.0 2436000.0 2438000.0 2440000.0 2442000.0 2444000.0 2446000.0 2448000.0 2450000.0 2452000.0 2454000.0 2456000.0 2458000.0 2460000.0 ]);
    set(gca,'XTickLabel',' 2418000|2420000|2422000|2424000|2426000|2428000|2430000|2432000|2434000|2436000|2438000|2440000|2442000|2444000|2446000|2448000|2450000|2452000|2454000|2456000|2458000|2460000');
else
    if ((maxJD-minJD) >= 15000) & ((maxJD-minJD) < 40000)  %od 27 let do cca 95 let
        set(gca,'XTick',[ 2415000.0 2420000.0 2425000.0 2430000.0 2435000.0 2440000.0 2445000.0 2450000.0 2455000.0 2460000.0 ]);
        set(gca,'XTickLabel','2415000|2420000|2425000|2430000|2435000|2440000|2445000|2450000|2455000|2460000');
    else
        set(gca,'XTick',[ 2420000.0 2430000.0 2440000.0 2450000.0 2460000.0 ]);
        set(gca,'XTickLabel','2420000|2430000|2440000|2450000|2460000');
    end
end 
set(gca,'TickDir','out', 'FontSize', Fonts);
set(gca,'XAxisLocation','top', 'FontSize', Fonts);
title(QQ);    %O-C diagram with the LITE curve, another format, better to publish

RECT=[0.9046 0.302 0.0001 0.432];
axes('position', RECT);
set(gca,'FontSize',Fonts);
axis([-0.01 0.01 minPer3 maxPer3]);
set(gca,'TickDir','in');
set(gca,'YAxisLocation','right', 'FontSize', Fonts);
ylabel('O-C (Period)', 'FontSize', Fonts);

clear CC;
CC=['3.png'];
BB=char(Star);
QQ=sprintf([BB CC]);
print('-f', '-dpng', QQ);      %transform the O-C diagram into the .png format
clear CCa;
CCa=['3.eps'];
QQ=sprintf([BB CCa]);
if ColFigs
    print('-f', '-depsc', QQ);      %transform the O-C diagram into the .eps format
else
    print('-f', '-deps', QQ);      %transform the O-C diagram into the .eps format
end
hold off

clear AA BB CC DD QQ;
%-----------------------------------------------------------------------

%here the figure after subtraction of MT but with the LITE curve
E=Epo0;
O=JDi-JD00-P*E-10^(-10)*qmt*E.*E;          %residuum ((O-C)-LITE)

j=1;
k=1;
for i = 1:N
   switch round(10*abs(E(i)-round(E(i))))
   case 0
      E11(j)=E(i);    %prim minimum
      Occ1(j)=O(i);
      B1(j)=Weight(i);
      j=j+1;
   case 5            %sec minimum
      E21(k)=E(i);
      Occ2(k)=O(i);   
      B2(k)=Weight(i);
      k=k+1;
   end
end

m=1;
n=1;
o=1;
o1=1;
for i = 1:j-1     %prim min
   switch B1(i)
   case 1        %vis prim min
      E1v(n)=E11(i);
      O1v(n)=Occ1(i);
      n=n+1;
   case 3        %phot prim min, worse
      E1pp(o1)=E11(i);
      O1pp(o1)=Occ1(i);
      o1=o1+1;
   case 5        %phot prim min
      E1p(o)=E11(i);
      O1p(o)=Occ1(i);
      o=o+1;
   case 10        %ccd prim min
      E1c(m)=E11(i);
      O1c(m)=Occ1(i);
      m=m+1;
   case 30        %ccd prim min
      E1c(m)=E11(i);
      O1c(m)=Occ1(i);
      m=m+1;
   end
end

p=1;
q=1;
r=1;
o2=1;
for i = 1:k-1     %sec min
   switch B2(i)
   case 1         %vis sec min
      E2v(p)=E21(i);
      O2v(p)=Occ2(i);
      p=p+1;
   case 3        %phot sec min, worse
      E2pp(o2)=E21(i);
      O2pp(o2)=Occ2(i);
      o2=o2+1;
  case 5         %phot sec min
      E2p(q)=E21(i);
      O2p(q)=Occ2(i);
      q=q+1;
   case 10        %ccd sec min
      E2c(r)=E21(i);
      O2c(r)=Occ2(i);
      r=r+1;
   case 30        %ccd sec min
      E2c(r)=E21(i);
      O2c(r)=Occ2(i);
      r=r+1;
   end
end

minimumO=Minimum(O,Weight,N)-0.01;
maximumO=Maximum(O,Weight,N)+0.01;
minPer=minimumO/P;
maxPer=maximumO/P;

Ep=minimumE:10:maximumE;        %plot a curve
JDi0=Ep*P+JD00+10^(-10)*qmt*Ep.*Ep;
Oc=OminusC(JDi0,T0,A,p3,omega,excen);

%-------------- 
clear CC;
CC=['2.txt'];
BB=char(Star);
QQ=sprintf([BB CC]);

OutputData=[JDi0; Ep; Oc ];

BB=char(Star);
%-------------- O U T P U T  DATA FILE --------------->>>
fid = fopen(QQ,'w');
fprintf(fid,'%s',BB,': JDi -- Epoch -- OnlyLITE');
fprintf(fid,'%s\n','');
fprintf(fid,'%12.6f   %6.5f   %2.6f\n',OutputData);
status=fclose('all');
%--------------
clear OutputData BB CC QQ fid;

minJD=minimumE*P+JD00-2400000;
maxJD=maximumE*P+JD00-2400000;
minDate=JulToDate(minJD+2400000);
maxDate=JulToDate(maxJD+2400000);

figure(6);
if m > 1 plot(E1c,O1c,'k.','MarkerSize',17); end   %prim ccd min
hold on
if n > 1 plot(E1v,O1v,'k.','MarkerSize',6); end    %prim vis min
if o > 1 plot(E1p,O1p,'k.','MarkerSize',12); end   %prim phot min
if p > 1 plot(E2v,O2v,'ko','MarkerSize',2); end    %sec vis min
if q > 1 plot(E2p,O2p,'ko','MarkerSize',3); end    %sec phot min
if r > 1 plot(E2c,O2c,'ko','MarkerSize',4); end    %sec ccd min
if o1 > 1 plot(E1pp,O1pp,'k.','MarkerSize',8); end   %prim phot min worse quality
if o2 > 1 plot(E2pp,O2pp,'ko','MarkerSize',2); end   %prim phot min worse quality
plot(Ep,Oc,'r-','LineWidth',Lines);
set(gca,'FontSize',Fonts);
axis([minimumE maximumE minimumO maximumO]);
set(gca,'XAxisLocation','bottom', 'FontSize', Fonts);
set(gca,'box','off');
set(gca,'YAxisLocation','left', 'FontSize', Fonts);
set(gca,'PlotBoxAspectRatio',[2.4 1 1]);
xlabel('Epoch', 'FontSize', Fonts);
set(gca,'FontSize',Fonts);
ylabel('O-C (days)', 'FontSize', Fonts);

RECT=[0.13 0.733603 0.775 0.0001];
axes('position', RECT);
set(gca,'FontSize',Fonts);
axis([minJD+2400000 maxJD+2400000 -0.001 0.001]);
set(gca,'XLimMode','manual');
if (maxJD-minJD) < 7000 %cca 19 let
    set(gca,'XTick',[ 2417000.0 2418000.0 2419000.0 2420000.0 2421000.0 2422000.0 2423000.0 2424000.0 2425000.0  2426000.0 2427000.0 2428000.0 2429000.0 2430000.0 2431000.0 2432000.0 2433000.0 2434000.0 2435000.0 2436000.0 2437000.0 2438000.0 2439000.0 2440000.0 2441000.0 2442000.0 2443000.0 2444000.0 2445000.0 2446000.0 2447000.0 2448000.0 2449000.0 2450000.0 2451000.0 2452000.0 2453000.0 2454000.0 2455000.0 2456000.0 2457000.0 2458000.0 2459000.0 2460000.0 ]);
    set(gca,'XTickLabel','2417000|2418000|2419000|2420000|2421000|2422000|2423000|2424000|2425000| 2426000|2427000|2428000|2429000|2430000|2431000|2432000|2433000|2434000|2435000|2436000|2437000|2438000|2439000|2440000|2441000|2442000|2443000|2444000|2445000|2446000|2447000|2448000|2449000|2450000|2451000|2452000|2453000|2454000|2455000|2456000|2457000|2458000|2459000|2460000');    
elseif ((maxJD-minJD) >= 7000) & ((maxJD-minJD) < 15000)  %od cca 19 let do 27 let
    set(gca,'XTick',[ 2418000.0 2420000.0 2422000.0 2424000.0 2426000.0 2428000.0 2430000.0 2432000.0 2434000.0 2436000.0 2438000.0 2440000.0 2442000.0 2444000.0 2446000.0 2448000.0 2450000.0 2452000.0 2454000.0 2456000.0 2458000.0 2460000.0 ]);
    set(gca,'XTickLabel',' 2418000|2420000|2422000|2424000|2426000|2428000|2430000|2432000|2434000|2436000|2438000|2440000|2442000|2444000|2446000|2448000|2450000|2452000|2454000|2456000|2458000|2460000');
else
    if ((maxJD-minJD) >= 15000) & ((maxJD-minJD) < 40000)  %od 27 let do cca 95 let
        set(gca,'XTick',[ 2415000.0 2420000.0 2425000.0 2430000.0 2435000.0 2440000.0 2445000.0 2450000.0 2455000.0 2460000.0 ]);
        set(gca,'XTickLabel','2415000|2420000|2425000|2430000|2435000|2440000|2445000|2450000|2455000|2460000');
    else
        set(gca,'XTick',[ 2420000.0 2430000.0 2440000.0 2450000.0 2460000.0 ]);
        set(gca,'XTickLabel','2420000|2430000|2440000|2450000|2460000');
    end
end 
set(gca,'TickDir','out', 'FontSize', Fonts);
set(gca,'XAxisLocation','top', 'FontSize', Fonts);

CC=['O-C diagram '];
BB=char(Star);
DD=[' after subtraction of parabola'];
QQ=sprintf([CC BB DD]);
title(QQ);    %O-C diagram with the LITE curve, another format, better to publish

RECT=[0.9046 0.302 0.0001 0.432];
axes('position', RECT);
set(gca,'FontSize',Fonts);
axis([-0.01 0.01 minPer maxPer]);
set(gca,'TickDir','in', 'FontSize', Fonts);
set(gca,'YAxisLocation','right');
ylabel('O-C (Period)', 'FontSize', Fonts);

RECT=[0.13 0.733603 0.775 0.0001];
axes('position', RECT);
axis([minDate maxDate -0.01 0.01]);
set(gca,'TickDir','out', 'FontSize', Fonts);
set(gca,'XAxisLocation','bottom');
% set(gca,'XTick',[ 1920.0 1930.0 1940.0 1950.0 1960.0 1970.0 1980.0 1990.0 2000.0 2010.0 2020.0 ]);
% set(gca,'XTickLabel','1920|1930|1940|1950|1960|1970|1980|1990|2000|2010|2020    ');

clear CC;
CC=['2.png'];
BB=char(Star);
QQ=sprintf([BB CC]);
print('-f', '-dpng', QQ);      %transform the O-C diagram into the .png format
clear CCa;
CCa=['2.eps'];
QQ=sprintf([BB CCa]);
if ColFigs
    print('-f', '-depsc', QQ);      %transform the O-C diagram into the .eps format
else
    print('-f', '-deps', QQ);      %transform the O-C diagram into the .eps format
end
hold off

clear AA BB CC DD QQ;
%-----------------------------------------------------
% and also after the subtraction of the LITE -------->>

Ocx=OminusC(JDi,T0,A,p3,omega,excen);
O=JDi-JD00-P*Epo0-Ocx-10^(-10)*qmt*Epo0.*Epo0;          %residuum ((O-C)-LITE)

%-------------- 
clear CC;
CC=['_Residuals.txt'];
BB=char(Star);
QQ=sprintf([BB CC]);

OutputData=[JDi'; Epo0'; O'];

BB=char(Star);
%-------------- O U T P U T  DATA FILE --------------->>>
fid = fopen(QQ,'w');
fprintf(fid,'%s',BB,': JDi -- Epoch -- O-C');
fprintf(fid,'%s\n','');
fprintf(fid,'%12.6f   %6.5f   %2.6f\n',OutputData);
status=fclose('all');
%--------------
clear OutputData BB CC QQ fid;

j=1;
k=1;
for i = 1:N
   switch round(10*abs(Epo0(i)-round(Epo0(i))))
   case 0
      E11(j)=Epo0(i);    %prim minimum
      Occ1(j)=O(i);
      B1(j)=Weight(i);
      j=j+1;
   case 5            %sec minimum
      E21(k)=Epo0(i);
      Occ2(k)=O(i);   
      B2(k)=Weight(i);
      k=k+1;
   end
end

m=1;
n=1;
o=1;
o1=1;
for i = 1:j-1     %prim min
   switch B1(i)
   case 1        %vis prim min
      E1v(n)=E11(i);
      O1v(n)=Occ1(i);
      n=n+1;
   case 3        %phot prim min, worse
      E1pp(o1)=E11(i);
      O1pp(o1)=Occ1(i);
      o1=o1+1;
   case 5        %phot prim min
      E1p(o)=E11(i);
      O1p(o)=Occ1(i);
      o=o+1;
   case 10        %ccd prim min
      E1c(m)=E11(i);
      O1c(m)=Occ1(i);
      m=m+1;
   case 30        %ccd prim min
      E1c(m)=E11(i);
      O1c(m)=Occ1(i);
      m=m+1;
   end
end

p=1;
q=1;
r=1;
o2=1;
for i = 1:k-1     %sec min
   switch B2(i)
   case 1         %vis sec min
      E2v(p)=E21(i);
      O2v(p)=Occ2(i);
      p=p+1;
   case 3        %phot sec min, worse
      E2pp(o2)=E21(i);
      O2pp(o2)=Occ2(i);
      o2=o2+1;
  case 5         %phot sec min
      E2p(q)=E21(i);
      O2p(q)=Occ2(i);
      q=q+1;
   case 10        %ccd sec min
      E2c(r)=E21(i);
      O2c(r)=Occ2(i);
      r=r+1;
   case 30        %ccd sec min
      E2c(r)=E21(i);
      O2c(r)=Occ2(i);
      r=r+1;
   end
end

minimumO=Minimum(O,Weight,N)-0.01;
maximumO=Maximum(O,Weight,N)+0.01;
minPer=minimumO/P;
maxPer=maximumO/P;

E=minimumE:10:maximumE;
O=0+0.0000000000001*E;

figure(7);
clf;
if m > 1 plot(E1c,O1c,'k.','MarkerSize',17); end   %prim ccd min
hold on
if n > 1 plot(E1v,O1v,'k.','MarkerSize',6); end    %prim vis min
if o > 1 plot(E1p,O1p,'k.','MarkerSize',12); end   %prim phot min
if p > 1 plot(E2v,O2v,'ko','MarkerSize',2); end    %sec vis min
if q > 1 plot(E2p,O2p,'ko','MarkerSize',3); end    %sec phot min
if r > 1 plot(E2c,O2c,'ko','MarkerSize',4); end    %sec ccd min
if o1 > 1 plot(E1pp,O1pp,'k.','MarkerSize',8); end   %prim phot min worse quality
if o2 > 1 plot(E2pp,O2pp,'ko','MarkerSize',2); end   %prim phot min worse quality
plot(E,O,'k','LineWidth',Lines);
set(gca,'FontSize',Fonts);
axis([minimumE maximumE minimumO maximumO]);
set(gca,'XAxisLocation','bottom', 'FontSize', Fonts);
set(gca,'box','off');
set(gca,'YAxisLocation','left', 'FontSize', Fonts);
set(gca,'PlotBoxAspectRatio',[2.4 1 1]);
% set(gca,'XTick',[ -15000.0 -10000.0 -5000.0 0.0 5000.0 10000.0 15000.0 ]);
% set(gca,'XTickLabel','-15000|-10000|-5000|0|5000|10000|15000');
xlabel('Epoch', 'FontSize', Fonts);
set(gca,'FontSize',Fonts);
ylabel('(O-C)-(O-C)_{LITE} (days)', 'FontSize', Fonts);

RECT=[0.13 0.733603 0.775 0.0001];
axes('position', RECT);
set(gca,'FontSize',Fonts);
axis([minDate maxDate -0.01 0.01]);
set(gca,'TickDir','out', 'FontSize', Fonts);
set(gca,'XAxisLocation','bottom');

RECT=[0.13 0.733603 0.775 0.0001];
axes('position', RECT);
axis([minJD+2400000 maxJD+2400000 -0.001 0.001]);
set(gca,'XLimMode','manual');
if (maxJD-minJD) < 7000 %cca 19 let
    set(gca,'XTick',[ 2417000.0 2418000.0 2419000.0 2420000.0 2421000.0 2422000.0 2423000.0 2424000.0 2425000.0  2426000.0 2427000.0 2428000.0 2429000.0 2430000.0 2431000.0 2432000.0 2433000.0 2434000.0 2435000.0 2436000.0 2437000.0 2438000.0 2439000.0 2440000.0 2441000.0 2442000.0 2443000.0 2444000.0 2445000.0 2446000.0 2447000.0 2448000.0 2449000.0 2450000.0 2451000.0 2452000.0 2453000.0 2454000.0 2455000.0 2456000.0 2457000.0 2458000.0 2459000.0 2460000.0 ]);
    set(gca,'XTickLabel','2417000|2418000|2419000|2420000|2421000|2422000|2423000|2424000|2425000| 2426000|2427000|2428000|2429000|2430000|2431000|2432000|2433000|2434000|2435000|2436000|2437000|2438000|2439000|2440000|2441000|2442000|2443000|2444000|2445000|2446000|2447000|2448000|2449000|2450000|2451000|2452000|2453000|2454000|2455000|2456000|2457000|2458000|2459000|2460000');    
elseif ((maxJD-minJD) >= 7000) & ((maxJD-minJD) < 15000)  %od cca 19 let do 27 let
    set(gca,'XTick',[ 2418000.0 2420000.0 2422000.0 2424000.0 2426000.0 2428000.0 2430000.0 2432000.0 2434000.0 2436000.0 2438000.0 2440000.0 2442000.0 2444000.0 2446000.0 2448000.0 2450000.0 2452000.0 2454000.0 2456000.0 2458000.0 2460000.0 ]);
    set(gca,'XTickLabel',' 2418000|2420000|2422000|2424000|2426000|2428000|2430000|2432000|2434000|2436000|2438000|2440000|2442000|2444000|2446000|2448000|2450000|2452000|2454000|2456000|2458000|2460000');
else
    if ((maxJD-minJD) >= 15000) & ((maxJD-minJD) < 40000)  %od 27 let do cca 95 let
        set(gca,'XTick',[ 2415000.0 2420000.0 2425000.0 2430000.0 2435000.0 2440000.0 2445000.0 2450000.0 2455000.0 2460000.0 ]);
        set(gca,'XTickLabel','2415000|2420000|2425000|2430000|2435000|2440000|2445000|2450000|2455000|2460000');
    else
        set(gca,'XTick',[ 2420000.0 2430000.0 2440000.0 2450000.0 2460000.0 ]);
        set(gca,'XTickLabel','2420000|2430000|2440000|2450000|2460000');
    end
end
set(gca,'TickDir','out', 'FontSize', Fonts);
set(gca,'XAxisLocation','top', 'FontSize', Fonts);

CC=['Residuals in (O-C) diagram '];
BB=char(Star);
QQ=sprintf([CC BB]);
title(QQ);    %O-C diagram with the LITE curve, another format, better to publish

RECT=[0.9046 0.302 0.0001 0.432];
axes('position', RECT);
set(gca,'FontSize',Fonts);
axis([-0.01 0.01 minPer maxPer]);
set(gca,'TickDir','in', 'FontSize', Fonts);
set(gca,'YAxisLocation','right');
ylabel('O-C (Period)', 'FontSize', Fonts);

clear CC;
CC=['Residuals.png'];
BB=char(Star);
QQ=sprintf([BB CC]);
print('-f', '-dpng', QQ);      %transform the O-C diagram into the .png format
clear CCa;
CCa=['Residuals.eps'];
QQ=sprintf([BB CCa]);
if ColFigs
    print('-f', '-depsc', QQ);      %transform the O-C diagram into the .eps format
else
    print('-f', '-deps', QQ);      %transform the O-C diagram into the .eps format
end
hold off

clear AA BB CC DD QQ;
%-----------------------------------------------------------------------
figure(8);
clf;
 set(gca,'Visible', 'off');
RECT=[0.1 0.33603 0.775 0.44];
axes('position', RECT);
plot(Ep3,Oc3,'r-','LineWidth',Lines);
hold on
plot(Ep3,+10^(-10)*qmt*Ep3.*Ep3,'b-.','LineWidth',Lines);
set(gca,'FontSize',Fonts);
axis([minimumE maximumE minimumO3 maximumO3]);
set(gca,'box','off');
set(gca,'TickDir','in', 'FontSize', Fonts);
set(gca,'XTickLabel','');
set(gca,'YAxisLocation','left', 'FontSize', Fonts); 
ylabel('O-C (days)', 'FontSize', Fonts);
if m > 1 plot(E1c,O31c,'k.','MarkerSize',17); end   %prim ccd min
if n > 1 plot(E1v,O31v,'k.','MarkerSize',6); end    %prim vis min
if o > 1 plot(E1p,O31p,'k.','MarkerSize',12); end   %prim phot min
if p > 1 plot(E2v,O32v,'ko','MarkerSize',2); end    %sec vis min
if q > 1 plot(E2p,O32p,'ko','MarkerSize',3); end    %sec phot min
if r > 1 plot(E2c,O32c,'ko','MarkerSize',4); end    %sec ccd min
if o1 > 1 plot(E1pp,O31pp,'k.','MarkerSize',8); end   %prim phot min worse quality
if o2 > 1 plot(E2pp,O32pp,'ko','MarkerSize',2); end   %prim phot min worse quality

%RECT=[0.13 0.80503 0.775 0.0001];
RECT=[0.10 0.7765 0.775 0.00001];
axes('position', RECT);
set(gca,'FontSize',Fonts);
axis([minDate maxDate -0.01 0.01]);
%set(gca,'XTickLabel','-15000|-10000|-5000|0|5000|10000|15000');
set(gca,'TickDir','out', 'FontSize', Fonts);
set(gca,'XAxisLocation','top');
set(gca,'XAxisLocation','bottom');

RECT=[0.10 0.7765 0.775 0.00001];
axes('position', RECT);
set(gca,'FontSize',Fonts);
axis([minJD+2400000 maxJD+2400000 -0.0001 0.0001]);
set(gca,'XLimMode','manual');
if (maxJD-minJD) < 7000 %cca 19 let
    set(gca,'XTick',[ 2417000.0 2418000.0 2419000.0 2420000.0 2421000.0 2422000.0 2423000.0 2424000.0 2425000.0  2426000.0 2427000.0 2428000.0 2429000.0 2430000.0 2431000.0 2432000.0 2433000.0 2434000.0 2435000.0 2436000.0 2437000.0 2438000.0 2439000.0 2440000.0 2441000.0 2442000.0 2443000.0 2444000.0 2445000.0 2446000.0 2447000.0 2448000.0 2449000.0 2450000.0 2451000.0 2452000.0 2453000.0 2454000.0 2455000.0 2456000.0 2457000.0 2458000.0 2459000.0 2460000.0 ]);
    set(gca,'XTickLabel','2417000|2418000|2419000|2420000|2421000|2422000|2423000|2424000|2425000| 2426000|2427000|2428000|2429000|2430000|2431000|2432000|2433000|2434000|2435000|2436000|2437000|2438000|2439000|2440000|2441000|2442000|2443000|2444000|2445000|2446000|2447000|2448000|2449000|2450000|2451000|2452000|2453000|2454000|2455000|2456000|2457000|2458000|2459000|2460000');    
elseif ((maxJD-minJD) >= 7000) & ((maxJD-minJD) < 15000)  %od cca 19 let do 27 let
    set(gca,'XTick',[ 2418000.0 2420000.0 2422000.0 2424000.0 2426000.0 2428000.0 2430000.0 2432000.0 2434000.0 2436000.0 2438000.0 2440000.0 2442000.0 2444000.0 2446000.0 2448000.0 2450000.0 2452000.0 2454000.0 2456000.0 2458000.0 2460000.0 ]);
    set(gca,'XTickLabel',' 2418000|2420000|2422000|2424000|2426000|2428000|2430000|2432000|2434000|2436000|2438000|2440000|2442000|2444000|2446000|2448000|2450000|2452000|2454000|2456000|2458000|2460000');
else
    if ((maxJD-minJD) >= 15000) & ((maxJD-minJD) < 40000)  %od 27 let do cca 95 let
        set(gca,'XTick',[ 2415000.0 2420000.0 2425000.0 2430000.0 2435000.0 2440000.0 2445000.0 2450000.0 2455000.0 2460000.0 ]);
        set(gca,'XTickLabel','2415000|2420000|2425000|2430000|2435000|2440000|2445000|2450000|2455000|2460000');
    else
        set(gca,'XTick',[ 2420000.0 2430000.0 2440000.0 2450000.0 2460000.0 ]);
        set(gca,'XTickLabel','2420000|2430000|2440000|2450000|2460000');
    end
end
set(gca,'TickDir','out', 'FontSize', Fonts);
set(gca,'XAxisLocation','top', 'FontSize', Fonts);

RECT=[0.8750 0.3356 0.0001 0.4415];
axes('position', RECT);
set(gca,'FontSize',Fonts);
axis([-0.01 0.01 minPer3 maxPer3]);
set(gca,'TickDir','in');
set(gca,'YAxisLocation','right', 'FontSize', Fonts);
ylabel('O-C (Period)', 'FontSize', Fonts);

RECT=[0.1 0.1389 0.775 0.22];
axes('position', RECT);
plot(E,O,'k-');
hold on
set(gca,'FontSize',Fonts);
axis([minimumE maximumE minimumO maximumO]);
set(gca,'box','off');
set(gca,'TickDir','in', 'FontSize', Fonts);
set(gca,'XTickLabel','');
set(gca,'YAxisLocation','left', 'FontSize', Fonts); 
ylabel('O-C (days)', 'FontSize', Fonts);
if m > 1 plot(E1c,O1c,'k.','MarkerSize',17); end   %prim ccd min
if n > 1 plot(E1v,O1v,'k.','MarkerSize',6); end    %prim vis min
if o > 1 plot(E1p,O1p,'k.','MarkerSize',12); end   %prim phot min
if p > 1 plot(E2v,O2v,'ko','MarkerSize',2); end    %sec vis min
if q > 1 plot(E2p,O2p,'ko','MarkerSize',3); end    %sec phot min
if r > 1 plot(E2c,O2c,'ko','MarkerSize',4); end    %sec ccd min
if o1 > 1 plot(E1pp,O1pp,'k.','MarkerSize',8); end   %prim phot min worse quality
if o2 > 1 plot(E2pp,O2pp,'ko','MarkerSize',2); end   %prim phot min worse quality
set(gca,'XAxisLocation','bottom', 'FontSize', Fonts);
set(gca,'YAxisLocation','left', 'FontSize', Fonts);
set(gca,'PlotBoxAspectRatio',[6 1 1]);
set(gca,'XTickLabelMode','auto');
% set(gca,'XTick',[ -15000.0 -10000.0 -5000.0 0.0 5000.0 10000.0 15000.0 ]);
% set(gca,'XTickLabel','-15000|-10000|-5000|0|5000|10000|15000');
xlabel('Epoch', 'FontSize', Fonts);
set(gca,'FontSize',Fonts);
% ylabel('(O-C)-(O-C)_{LITE} (days)', 'FontSize', 12);
ylabel('', 'FontSize', Fonts);

RECT=[0.8750 0.1623 0.0001 0.173];
axes('position', RECT);
set(gca,'FontSize',Fonts);
axis([-0.01 0.01 minPer maxPer]);
set(gca,'TickDir','in');
set(gca,'YAxisLocation','right', 'FontSize', Fonts);
% ylabel('O-C (Period)', 'FontSize', Fonts);

clear CC;
CC=['Complet.png'];
BB=char(Star);
QQ=sprintf([BB CC]);
print('-f', '-dpng', QQ);     %transform the O-C diagram into the .png format
clear CCa;
CCa=['Complet.eps'];
QQ=sprintf([BB CCa]);
if ColFigs
    print('-f', '-depsc', QQ);      %transform the O-C diagram into the .eps format
else
    print('-f', '-deps', QQ);      %transform the O-C diagram into the .eps format
end
hold off

clear AA BB CC DD QQ;
%-----------------------------------------------------------------------
% here solve the minimal mass M3min from M12 and f(M3)
m3min = CalculateMass(90,M1+M2,fm3);
m360 = CalculateMass(60,M1+M2,fm3);
m330 = CalculateMass(30,M1+M2,fm3);
  
BB=char(Star);
CC=['        ; 1=compute, 0=not compute'];
BBa=char(Star);
QQ=sprintf([BBa CC]);
%-------------- O U T P U T --------------->>>
fid = fopen('Parameters.txt','w');
fprintf(fid,'%s\n',QQ');
fprintf(fid,'%12.5f',JD00);
fprintf(fid,'%s','   ');
fprintf(fid,'%1.0f',JD0F);
fprintf(fid,'%s','   ');
fprintf(fid,'%s\n','   JD0');
fprintf(fid,'%2.10f',P);
fprintf(fid,'%s','    ');
fprintf(fid,'%1.0f',PF);
fprintf(fid,'%s','   ');
fprintf(fid,'%s\n','   P(days)');
fprintf(fid,'%3.2f',p3);
fprintf(fid,'%s','        ');
fprintf(fid,'%1.0f',p3F);
fprintf(fid,'%s','   ');
fprintf(fid,'%s\n','   p3(days)');
fprintf(fid,'%10.2f', T0);
fprintf(fid,'%s','      ');
fprintf(fid,'%1.0f',T0F);
fprintf(fid,'%s','   ');
fprintf(fid,'%s\n','   T0');
fprintf(fid,'%1.6f',A);
fprintf(fid,'%s','        ');
fprintf(fid,'%1.0f',AF);
fprintf(fid,'%s','   ');
fprintf(fid,'%s\n','   A(days)');
fprintf(fid,'%4.3f',omega);
fprintf(fid,'%s','         ');
fprintf(fid,'%1.0f',omegaF);
fprintf(fid,'%s','   ');
fprintf(fid,'%s\n','   omega(deg)');
fprintf(fid,'%1.5f',excen);
fprintf(fid,'%s','         ');
fprintf(fid,'%1.0f',excenF);
fprintf(fid,'%s','   ');
fprintf(fid,'%s\n','   e');
fprintf(fid,'%2.5f',qmt);
fprintf(fid,'%s','       ');
fprintf(fid,'%1.0f',qmtF);
fprintf(fid,'%s','   ');
fprintf(fid,'%s\n','   qmt');
fprintf(fid,'%2.2f',M1);
fprintf(fid,'%s','            0   ');
fprintf(fid,'%s\n','   M1');
fprintf(fid,'%2.2f',M2);
fprintf(fid,'%s','            0   ');
fprintf(fid,'%s\n','   M2');
fprintf(fid,'%2.2f',paralax);
fprintf(fid,'%s','            0   ');
fprintf(fid,'%s\n','   pi(mas)');
fprintf(fid,'%2.2f',Fonts);
fprintf(fid,'%s','            0   ');
fprintf(fid,'%s\n','   Font size');
fprintf(fid,'%2.2f',Lines);
fprintf(fid,'%s','            0   ');
fprintf(fid,'%s\n','   Line width');
fprintf(fid,'%2.2f',ColFigs);
fprintf(fid,'%s','            0   ');
fprintf(fid,'%s\n','   Color(0) or Black and white(1) figures');
status=fclose('all');
%--------------------------------------------

if qmt ~= 0
    
%===========Calculation of the uncertainity of the ephemeris!!!===================
M=3;   %number of parameters to fit (only 2 parameters)
%--------------------------------------------------
yiminusyxi = (JDi-JD00-P*Epo0)-10^(-10)*qmt*(Epo0.*Epo0);   %y_i - y(x_i,p3,A,T0,e,omega,q)
sigmaKvadra = (sum(yiminusyxi.*yiminusyxi))/(N-M);

dydJD0  =  ((JD00+0.0001+P*Epo0) - (JD00+P*Epo0))/0.0001;    %d(OminusC)/dJD0
dydP  =  ((JD00+(P+0.0000001)*Epo0) - (JD00+P*Epo0))/0.0000001;       %d(OminusC)/dP
dydq  =  (((JDi-JD00-P*Epo0)-10^(-10)*(qmt+0.001)*(Epo0.*Epo0)) - ((JDi-JD00-P*Epo0)-10^(-10)*qmt*(Epo0.*Epo0)))/0.001; %d(OminusC)/dq

for k = 1:M
    for l = 1:M
        switch k
            case 1
                first = dydJD0;
            case 2 
                first = dydP;
            case 3 
                first = dydq;
        end
        switch l
            case 1
                second = dydJD0;
            case 2 
                second = dydP;
            case 3
                second = dydq;
        end
        alpha(k,l) = (1/sigmaKvadra)*(sum((first).*(second)));
    end
end

C=inv(alpha);
sigma=sqrt(C);
% disp('Absolute errors:');
sigmaJD0c=sigma(1,1);
sigmaPc=sigma(2,2);
sigmaqc=sigma(3,3);

% disp(['Relative errors: JD0 => ',num2str(100*sigmaJD0/JD00,'%4.4f'),' %']);
% disp(['Relative errors: P => ',num2str(100*sigmaP/P,'%4.4f'),' %']);
clear alpha C sigma M yiminusyxi sigmaKvadra dydJD0 dydP dydq k l first second;
%=========================================================================

end


if qmt == 0
    M=7;   %number of parameters to fit (only 5 parameters of the LITE + efemerides)

    omega3=omega;   %deg
    excen3=excen;

    yiminusyxi = (JDi-JD00-P*Epo0-10^(-10)*qmt*(Epo0.*Epo0))-(OminusC(JDi,T0,A,p3,omega3,excen3));   %y_i - y(x_i,p3,A,T0,e,omega)
    sigmaKvadrat = (sum(yiminusyxi.*yiminusyxi))/(N-M);

    dydp3  =  (OminusC(JDi,T0,A,p3+0.00001,omega3,excen3) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.00001;    %d(OminusC)/dp3
    dydTO  =  (OminusC(JDi,T0+0.00001,A,p3,omega3,excen3) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.00001;       %d(OminusC)/dTO
    dydA = (OminusC(JDi,T0,A+0.0000001,p3,omega3,excen3) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.0000001;  %d(OminusC)/dA
    dydomeg = (OminusC(JDi,T0,A,p3,omega3+0.0000001,excen3) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.0000001;    %d(OminusC)/domega
    dyde  =  (OminusC(JDi,T0,A,p3,omega3,excen3+0.0000001) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.0000001;    %d(OminusC)/de
    dydJD0  =  ((JD00+0.00001+P*Epo0) - (JD00+P*Epo0))/0.00001;    %d(OminusC)/dJD0
    dydP  =  ((JD00+(P+0.00000001)*Epo0) - (JD00+P*Epo0))/0.00000001;       %d(OminusC)/dP

    for k = 1:M
        for l = 1:M
            switch k
                case 1 
                   first = dydp3;
                case 2 
                   first = dydTO;
                case 3 
                   first = dydA;
                case 4 
                   first = dydomeg;
                case 5 
                   first = dyde;
                case 6
                   first = dydJD0;
                case 7 
                   first = dydP;
          end
          switch l
              case 1 
                   second = dydp3;
              case 2 
                   second = dydTO;
              case 3 
                   second = dydA;
              case 4 
                   second = dydomeg;
              case 5 
                   second = dyde;
              case 6
                   second = dydJD0;
              case 7 
                   second = dydP;
           end
           alfa(k,l) = (1/sigmaKvadrat)*(sum((first).*(second)));
       end
    end

    C=inv(alfa);
    sigma=sqrt(C);
%     disp('Absolute errors: ');
    sigmap3=sigma(1,1);
    sigmaT0=sigma(2,2);
    sigmaA=sigma(3,3);
    sigmaomega=sigma(4,4);
    sigmaexc=sigma(5,5);
    sigmaJD0b=sigma(6,6);
    sigmaPb=sigma(7,7);

%     disp(['Relative errors: p3 => ',num2str(100*sigmap3/p3,'%4.4f'),' %']);
%     disp(['Relative errors: T0 => ',num2str(100*sigmaT0/T0,'%4.4f'),' %']);
%     disp(['Relative errors: A  => ',num2str(100*sigmaA/A,'%4.4f'),' %']);
%     disp(['Relative errors: omega => ',num2str(100*sigmaomega/omega3,'%4.4f'),' %']);
%     disp(['Relative errors: e => ',num2str(100*sigmaexc/excen3,'%4.4f'),' %']);
%     disp(['Relative errors: JD0 => ',num2str(100*sigmaJD0/JD00,'%4.4f'),' %']);
%     disp(['Relative errors: P => ',num2str(100*sigmaP/P,'%4.4f'),' %']);

    fm3=1/(p3/365.24)^2*((173.14*A/sqrt(1-(excen3*cos(omega3*pi/180))^2 ))^3);

    p3=p3/365.24;
    sigmap3=sigmap3/365.24;
    sigmaomega=sigmaomega*pi/180;  %rad
    ErrChQ=(sigmap3)^2*(-2/3)^2*(p3^(-5/3)*173.14*A/sqrt(1-excen3^2*(cos(omega3*pi/180))^2))^2  + sigmaA^2*(173.14*p3^(-2/3)/sqrt(1-excen3^2*(cos(omega3*pi/180))^2))^2  +  sigmaexc^2*(173.14*A*p3^(-2/3)*(-1/2)*(1-excen3^2*(cos(omega3*pi/180))^2)^(-3/2)*(-2*excen3*(cos(omega3*pi/180))^2))^2  +  sigmaomega^2*(173.14*A*p3^(-2/3)*(-1/2)*(1-excen3^2*(cos(omega3*pi/180))^2)^(-3/2)*excen3^2*sin(2*omega3*pi/180))^2;

    p3=p3*365.24;

    ErrFM3=(ErrChQ)*fm3*sqrt(3);
    
%     disp(['Relative errors: fm3 => ',num2str(100*ErrFM3/fm3,'%4.4f'),' %']);

    clear alfa yiminusyxi sigmaKvadrat dydJD0 dydP first second k l C sigma ErrChQ;
else
    M=8;   %number of parameters to fit (only 5 parameters of the LITE + MT + efemerides)
    
    omega3=omega;   %deg
    excen3=excen;
    clear alfa;

    yiminusyxi = (JDi-JD00-P*Epo0)-(OminusC(JDi,T0,A,p3,omega3,excen3)+10^(-10)*qmt*(Epo0.*Epo0));   %y_i - y(x_i,p3,A,T0,e,omega,q)
    sigmaKvadrat = (sum(yiminusyxi.*yiminusyxi))/(N-M);

    dydp3  =  (OminusC(JDi,T0,A,p3+0.00001,omega3,excen3) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.00001;    %d(OminusC)/dp3
    dydTO  =  (OminusC(JDi,T0+0.0001,A,p3,omega3,excen3) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.0001;     %d(OminusC)/dTO
    dydA = (OminusC(JDi,T0,A+0.0000001,p3,omega3,excen3) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.0000001;  %d(OminusC)/dA
    dydomeg = (OminusC(JDi,T0,A,p3,omega3+0.01,excen3) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.01;    %d(OminusC)/domega
    dyde  =  (OminusC(JDi,T0,A,p3,omega3,excen3+0.000001) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.000001;    %d(OminusC)/de
    dydq  =  ((OminusC(JDi,T0,A,p3,omega3,excen3+0.00000001)+10^(-10)*(qmt+0.00001)*(Epo0.*Epo0))- (OminusC(JDi,T0,A,p3,omega3,excen3)+10^(-10)*qmt*(Epo0.*Epo0)))/0.00000001;    %d(OminusC)/dq
    dydJD0  =  ((JD00+0.00001+P*Epo0) - (JD00+P*Epo0))/0.00001;    %d(OminusC)/dJD0
    dydP  =  ((JD00+(P+0.00000001)*Epo0) - (JD00+P*Epo0))/0.00000001;       %d(OminusC)/dP

    for k = 1:M
        for l = 1:M
            switch k
                case 1
                    first = dydp3;
                case 2
                    first = dydTO;
                case 3
                    first = dydA;
               case 4
                   first = dydomeg;
               case 5
                   first = dyde;
               case 6
                    first = dydq;
               case 7
                first = dydJD0;
               case 8 
                first = dydP;
            end
            switch l
                case 1
                    second = dydp3;
                case 2
                    second = dydTO;
                case 3
                    second = dydA;
                case 4
                    second = dydomeg;
                case 5
                    second = dyde;
                case 6
                    second = dydq;
                case 7
                    second = dydJD0;
                case 8 
                    second = dydP;
            end
            alfa(k,l) = (1/sigmaKvadrat)*(sum((first).*(second)));
        end
    end

    C=inv(0.5*alfa);
    sigma=sqrt(C);
%     disp('Absolute errors:');
    sigmap3=sigma(1,1);
    sigmaT0=sigma(2,2);
    sigmaA=sigma(3,3);
    sigmaomega=sigma(4,4);
    sigmaexc=sigma(5,5);
    sigmaqb=sigma(6,6);
    sigmaJD0b=sigma(7,7);
    sigmaPb=sigma(8,8);

%     disp(['Relative errors: p3 => ',num2str(100*sigmap3/p3,'%4.4f'),' %']); 
%     disp(['Relative errors: T0 => ',num2str(100*sigmaT0/T0,'%4.4f'),' %']); 
%     disp(['Relative errors: A  => ',num2str(100*sigmaA/A,'%4.4f'),' %']); 
%     disp(['Relative errors: omeg => ',num2str(100*sigmaomega/omega3,'%4.4f'),' %']); 
%     disp(['Relative errors: e => ',num2str(100*sigmaexc/excen3,'%4.4f'),' %']); 
%     disp(['Relative errors: q => ',num2str(100*sigmaq/(qmt+0.000000001),'%4.4f'),' %']);
%     disp(['Relative errors: JD0 => ',num2str(100*sigmaJD0/JD00,'%4.4f'),' %']);
%     disp(['Relative errors: P => ',num2str(100*sigmaP/P,'%4.4f'),' %']);

    fm3=1/(p3/365.24)^2*((173.14*A/sqrt(1-(excen3*cos(omega3*pi/180))^2 ))^3);

    p3=p3/365.24;
    sigmap3=sigmap3/365.24;
    sigmaomega=sigmaomega*pi/180;  %rad
    ErrChQ=(sigmap3)^2*(-2/3)^2*(p3^(-5/3)*173.14*A/sqrt(1-excen3^2*(cos(omega3*pi/180))^2))^2  + sigmaA^2*(173.14*p3^(-2/3)/sqrt(1-excen3^2*(cos(omega3*pi/180))^2))^2  +  sigmaexc^2*(173.14*A*p3^(-2/3)*(-1/2)*(1-excen3^2*(cos(omega3*pi/180))^2)^(-3/2)*(-2*excen3*(cos(omega3*pi/180))^2))^2  +  sigmaomega^2*(173.14*A*p3^(-2/3)*(-1/2)*(1-excen3^2*(cos(omega3*pi/180))^2)^(-3/2)*excen3^2*sin(2*omega3*pi/180))^2;

    p3=p3*365.24;
    
    ErrFM3=(ErrChQ)*fm3*sqrt(3);
    
%     disp(['Relative errors: fm3 => ',num2str(100*ErrFM3/fm3,'%4.4f'),' %']);

    clear alfa yiminusyxi sigmaKvadrat dydJD0 dydP first second k l C sigma ErrChQ;
end


M=5;   %number of parameters to fit (only 5 parameters of the LITE + MT + efemerides)
    
    omega3=omega;   %deg
    excen3=excen;
    clear alfa;

    yiminusyxi = (JDi-JD00-P*Epo0)-(OminusC(JDi,T0,A,p3,omega3,excen3)+10^(-10)*qmt*(Epo0.*Epo0));   %y_i - y(x_i,p3,A,T0,e,omega,q)
    sigmaKvadrat = (sum(yiminusyxi.*yiminusyxi))/(N-M);

    dydp3X  =  (OminusC(JDi,T0,A,p3+0.00001,omega3,excen3) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.00001;    %d(OminusC)/dp3
    dydTOX  =  (OminusC(JDi,T0+0.0001,A,p3,omega3,excen3) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.0001;     %d(OminusC)/dTO
    dydAX = (OminusC(JDi,T0,A+0.0000001,p3,omega3,excen3) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.0000001;  %d(OminusC)/dA
    dydomegX = (OminusC(JDi,T0,A,p3,omega3+0.001,excen3) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.001;    %d(OminusC)/domega
    dydeX  =  (OminusC(JDi,T0,A,p3,omega3,excen3+0.00001) - OminusC(JDi,T0,A,p3,omega3,excen3))/0.00001;    %d(OminusC)/de

    for k = 1:M
        for l = 1:M
            switch k
                case 1
                    first = dydp3X;
                case 2
                    first = dydTOX;
                case 3
                    first = dydAX;
               case 4
                   first = dydomegX;
               case 5
                   first = dydeX;
            end
            switch l
                case 1
                    second = dydp3X;
                case 2
                    second = dydTOX;
                case 3
                    second = dydAX;
                case 4
                    second = dydomegX;
                case 5
                    second = dydeX;
            end
            alfa(k,l) = (1/sigmaKvadrat)*(sum((first).*(second)));
        end
    end

    C=inv(alfa);
    sigma=sqrt(C);
%     disp('Absolute errors:');
    sigmap3X=sigma(1,1);
    sigmaT0X=sigma(2,2);
    sigmaAX=sigma(3,3);
    sigmaomegaX=sigma(4,4);
    sigmaexcX=sigma(5,5);

    p3=p3/365.24;
    sigmap3X=sigmap3X/365.24;
    sigmaomegaX=sigmaomegaX*pi/180;  %rad
    ErrChQX=(sigmap3)^2*(-2/3)^2*(p3^(-5/3)*173.14*A/sqrt(1-excen3^2*(cos(omega3*pi/180))^2))^2  + sigmaA^2*(173.14*p3^(-2/3)/sqrt(1-excen3^2*(cos(omega3*pi/180))^2))^2  +  sigmaexc^2*(173.14*A*p3^(-2/3)*(-1/2)*(1-excen3^2*(cos(omega3*pi/180))^2)^(-3/2)*(-2*excen3*(cos(omega3*pi/180))^2))^2  +  sigmaomega^2*(173.14*A*p3^(-2/3)*(-1/2)*(1-excen3^2*(cos(omega3*pi/180))^2)^(-3/2)*excen3^2*sin(2*omega3*pi/180))^2;

    p3=p3*365.24;
    
    ErrFM3X=(ErrChQX)*fm3*sqrt(3);
    
    clear alfa yiminusyxi sigmaKvadrat dydJD0 dydP first second k l C sigma ErrChQ;

    %-------------------------------
    
    ErrFM3=min(ErrFM3X,ErrFM3);
    sigmaA=min(sigmaAX,sigmaA);
    sigmap3=min(sigmap3X,sigmap3);
    sigmaT0=min(sigmaT0X,sigmaT0);
    sigmaomega=min(sigmaomegaX,sigmaomega);
    sigmaexc=min(sigmaexcX,sigmaexc); 

if (fm3 ~= 0) & (M12 ~= 0)

pocet=0;
zdar=1;
m3max(zdar)=m3min;
for ii = 90:1:90
    for fm3i = fm3-ErrFM3:(2*ErrFM3)/50:fm3+ErrFM3
        m3dalsi=abs(CalculateMass(ii,M12,fm3i));
        if abs(m3dalsi) > max(m3max)
            zdar=zdar+1;
            m3max(zdar) = m3dalsi;
%              defi=ii;
%              deffm3=fm3i;
        end
    end
end
mMaximalni=m3max(zdar);
clear zdar m3dalsi;

pocet=0;
zdar0=1;
m3minim(zdar0)=m3min;
j = 0;
for ii = 90:1:90
    for fm3i = fm3-ErrFM3:(2*ErrFM3)/50:fm3+ErrFM3
                    j = j+1;
        m3dalsi(j)=abs(CalculateMass(ii,M12,fm3i));
        if abs(m3dalsi(j)) < min(m3minim)
            zdar0=zdar0+1;
            m3minim(zdar0) = m3dalsi(j);
%              defi0=ii;
%              deffm30=fm3i;
        end
    end
end
mMinimalni=m3minim(zdar0);
clear zdar;
ChybaM3=1.0*max(m3min-mMinimalni,mMaximalni-m3min);

%------------------------------

pocet=0;
zdar=1;
m3max(zdar)=m360;
for ii = 60:1:60
    for fm3i = fm3-ErrFM3:(2*ErrFM3)/50:fm3+ErrFM3
        m3dalsi=abs(CalculateMass(ii,M12,fm3i));
        if abs(m3dalsi) > max(m3max)
            zdar=zdar+1;
            m3max(zdar) = m3dalsi;
%              defi=ii;
%              deffm3=fm3i;
        end
    end
end
mMaximalni=m3max(zdar);
clear zdar m3dalsi;

pocet=0;
zdar0=1;
m3minim(zdar0)=m360;
j = 0;
for ii = 60:1:60
    for fm3i = fm3-ErrFM3:(2*ErrFM3)/50:fm3+ErrFM3
                    j = j+1;
        m3dalsi(j)=abs(CalculateMass(ii,M12,fm3i));
        if abs(m3dalsi(j)) < min(m3minim)
            zdar0=zdar0+1;
            m3minim(zdar0) = m3dalsi(j);
%              defi0=ii;
%              deffm30=fm3i;
        end
    end
end
mMinimalni=m3minim(zdar0);
clear zdar;
ChybaM360=1.0*max(m360-mMinimalni,mMaximalni-m360);

%----------------------------------

pocet=0;
zdar=1;
m3max(zdar)=m330;
for ii = 30:1:30
    for fm3i = fm3-ErrFM3:(2*ErrFM3)/50:fm3+ErrFM3
        m3dalsi=abs(CalculateMass(ii,M12,fm3i));
        if abs(m3dalsi) > max(m3max)
            zdar=zdar+1;
            m3max(zdar) = m3dalsi;
%              defi=ii;
%              deffm3=fm3i;
        end
    end
end
mMaximalni=m3max(zdar);
clear zdar m3dalsi;

pocet=0;
zdar0=1;
m3minim(zdar0)=m330;
j = 0;
for ii = 30:1:30
    for fm3i = fm3-ErrFM3:(2*ErrFM3)/50:fm3+ErrFM3
                    j = j+1;
        m3dalsi(j)=abs(CalculateMass(ii,M12,fm3i));
        if abs(m3dalsi(j)) < min(m3minim)
            zdar0=zdar0+1;
            m3minim(zdar0) = m3dalsi(j);
%              defi0=ii;
%              deffm30=fm3i;
        end
    end
end
mMinimalni=m3minim(zdar0);
clear zdar;
ChybaM330=1.0*max(m330-mMinimalni,mMaximalni-m330);
%---------------------------------

else
   ChybaM3 = 0;
   ChybaM360 = 0;
   ChybaM330 = 0;
end

if paralax == 0
    a = 0;
else
    vzdalenostPC = 1/sin(paralax/1000);  %distance in PC
    i3=90;
    omega3=omega;
    excen3=excen;
    a12=abs(173.14*A/(sin(i3*pi/180)*sqrt(1-excen3^2*(cos(omega3*pi/180))^2)));  %poloosa obehu 3.slozky v AU
    m3def=CalculateMass(i3,M12,fm3);   %solar mass
    a3=a12*M12/m3def;
    a =180/pi*60*60*asin((a12+a3)/(206265*vzdalenostPC));   %uhlova poloosa obehu v arcsec
end

% disp(['Angular separation a [mas]: => ',num2str(a*1000,'%4.4f')]);

if sigmaJD0b == Inf
    sigmaJD0 = sigmaJD0a;
elseif (exist('sigmaJD0c') ~= 0)
    sigmaJD0 = min(min(sigmaJD0a,sigmaJD0b),sigmaJD0c);
else
    sigmaJD0 = min(sigmaJD0a,sigmaJD0b);
end

if sigmaPb == Inf
    sigmaP = sigmaPa;
elseif (exist('sigmaPc') ~= 0)
    sigmaP = min(min(sigmaPa,sigmaPb),sigmaPc);
else
    sigmaP = min(sigmaPa,sigmaPb);
end

if qmt ~= 0
    sigmaq = min(sigmaqb,sigmaqc);
else
    sigmaq = 0;
end

%-------------- O U T P U T --------------->>>
fid = fopen('Output.txt','w');
fprintf(fid,'%s',BB,': Final parameters');
fprintf(fid,'%s\n','');
fprintf(fid,'%s\n','');
fprintf(fid,'%s','JD0 = ');
fprintf(fid,'%12.7f',JD00);
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f',sigmaJD0);
fprintf(fid,'%s\n',' HJD');
fprintf(fid,'%s','P = ');
fprintf(fid,'%2.12f',P);
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f',sigmaP);
fprintf(fid,'%s\n',' days');
fprintf(fid,'%s\n','');
fprintf(fid,'%s','p3 = ');
fprintf(fid,'%3.4f',p3);
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f',sigmap3*365.24);
fprintf(fid,'%s\n',' days');
fprintf(fid,'%s','p3 = ');
fprintf(fid,'%5.4f',p3/365.24);
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f',sigmap3);
fprintf(fid,'%s\n',' years');
fprintf(fid,'%s','T0 = ');
fprintf(fid,'%10.3f',T0);
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f',sigmaT0);
fprintf(fid,'%s\n',' HJD');
fprintf(fid,'%s','A = ');
fprintf(fid,'%1.7f',A);
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f',sigmaA);
fprintf(fid,'%s\n',' days');
fprintf(fid,'%s','omega = ');
fprintf(fid,'%4.4f',omega);
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f',sigmaomega*180/pi);
fprintf(fid,'%s\n',' deg');
fprintf(fid,'%s','e = ');
fprintf(fid,'%1.7f',excen);
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f\n',sigmaexc);
fprintf(fid,'%s\n','');
if qmt == 0
    fprintf(fid,'%s\n','qmt = not computed');
else
    fprintf(fid,'%s','qmt = ');
    fprintf(fid,'%4.4f',qmt);
    fprintf(fid,'%s',' +/- ');
    fprintf(fid,'%3.8f',sigmaq);
    fprintf(fid,'%s\n',' .10^(-10)');  %  CORRECTED!
end
fprintf(fid,'%s\n','');
fprintf(fid,'%s','a12 sin i [AU] = ');
fprintf(fid,'%3.8f',A*173.14/(sqrt(1-excen^2*(cos(omega*pi/180))^2)));
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f',(A*173.14/(sqrt(1-excen^2*(cos(omega*pi/180))^2)))*sigmaA/A);
fprintf(fid,'%s\n','');
fprintf(fid,'%s\n','');
fprintf(fid,'%s','f(m3) = ');
fprintf(fid,'%4.10f',fm3);
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f',ErrFM3);
fprintf(fid,'%s\n',' M_sun');
fprintf(fid,'%s','M3(i=90) = ');
fprintf(fid,'%4.9f',m3min);
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f',ChybaM3);
fprintf(fid,'%s\n',' M_sun');
fprintf(fid,'%s','M3(i=60) = ');
fprintf(fid,'%4.9f',m360);
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f',ChybaM360);
fprintf(fid,'%s\n',' M_sun');
fprintf(fid,'%s','M3(i=30) = ');
fprintf(fid,'%4.9f',m330);
fprintf(fid,'%s',' +/- ');
fprintf(fid,'%3.8f',ChybaM330);
fprintf(fid,'%s\n',' M_sun');
fprintf(fid,'%s\n','');
fprintf(fid,'%s','Parallax:  pi = ');
fprintf(fid,'%2.3f',paralax);
fprintf(fid,'%s\n',' mas  => ');
fprintf(fid,'%s','Angular distance of 3.component: a = ');
fprintf(fid,'%3.3f',a*1000);
fprintf(fid,'%s\n',' mas ');
fprintf(fid,'%s\n','');
fprintf(fid,'%s','SUM of the square residuals: ');
fprintf(fid,'%1.13f\n',fl);
status=fclose('all');
%=========================================

% here solve the minimal mass M3min from M12 and f(M3)
i=0;
for n = 10:5:90
    i=i+1;
    i3(i) = n;
    m3def(i)=CalculateMass(i3(i),M1+M2,fm3);   %in solar masses
end

figure(9);
clf;
hold on
set(gca,'FontSize',Fonts);
set(gca,'box','on');
set(gca,'XGrid', 'on');
set(gca,'YGrid', 'on');
ylabel('Mass (M_{Sun})', 'FontSize', Fonts);
xlabel('Inclination (deg)', 'FontSize', Fonts);
set(gca,'PlotBoxAspectRatio',[2.4 1 1]);
plot(i3,m3def,'k.-','MarkerSize',10);

clear CC;
CC=['_Mass.png'];
BB=char(Star);
QQ=sprintf([BB CC]);
print('-f', '-dpng', QQ);      %transform the O-C diagram into the .png format
clear CCa;
CCa=['_Mass.eps'];
QQ=sprintf([BB CCa]);
if ColFigs
    print('-f', '-depsc', QQ);      %transform the O-C diagram into the .eps format
else
    print('-f', '-deps', QQ);      %transform the O-C diagram into the .eps format
end
hold off

clear AA BB CC DD QQ m3def i3 i;
%-----------------------------------------------------------------------
